@@ -22,10 +22,17 @@
 //file modified by richie
 require_once('include/utils/utils.php');
 require("modules/Emails/class.phpmailer.php");
-require_once("include/database/PearDatabase.php");
 require_once('include/logging.php');
 require("config.php");
 
+// Set the default sender email id
+global $HELPDESK_SUPPORT_EMAIL_ID;
+$from = $HELPDESK_SUPPORT_EMAIL_ID;
+if(empty($from)) {
+	// default configuration is empty?
+	$from = "reminders@localserver.com";
+}
+			
 // Get the list of activity for which reminder needs to be sent
 
 global $adb;
@@ -73,7 +80,7 @@ if($adb->num_rows($result) >= 1)
 
 	        $activity_time = strtotime(date("$date_start $time_start"))/60;
 
-		if (($activity_time - $curr_time) > 0 && ($activity_time - $curr_time) == $reminder_time)
+		if (($activity_time - $curr_time) > 0 && ($activity_time - $curr_time) <= $reminder_time)
 		{
 			$log->debug(" InSide  REMINDER");
 			$query_user="SELECT vtiger_users.email1,vtiger_salesmanactivityrel.smid FROM vtiger_salesmanactivityrel inner join vtiger_users on vtiger_users.id=vtiger_salesmanactivityrel.smid where vtiger_salesmanactivityrel.activityid =? and vtiger_users.deleted=0"; 
@@ -89,9 +96,6 @@ if($adb->num_rows($result) >= 1)
 				}
 			}
 		
-				// Set the preferred email id
-			$from ="reminders@localserver.com";
-			
 			// Retriving the Subject and message from reminder table		
 			$sql = "select active,notificationsubject,notificationbody from vtiger_notificationscheduler where schedulednotificationid=8";
 			$result_main = $adb->pquery($sql, array());
