@@ -1,19 +1,18 @@
 <?php
-/*********************************************************************************
-** The contents of this file are subject to the vtiger CRM Public License Version 1.0
+/*+********************************************************************************
+ * The contents of this file are subject to the vtiger CRM Public License Version 1.0
  * ("License"); You may not use this file except in compliance with the License
  * The Original Code is:  vtiger CRM Open Source
  * The Initial Developer of the Original Code is vtiger.
  * Portions created by vtiger are Copyright (C) vtiger.
  * All Rights Reserved.
-*
  ********************************************************************************/
 require_once('include/logging.php');
 require_once('include/database/PearDatabase.php');
 global $adb;
 
-$cvid = $_REQUEST["cvid"];
-$cvmodule = $_REQUEST["cvmodule"];
+$cvid = vtlib_purify($_REQUEST["cvid"]);
+$cvmodule = vtlib_purify($_REQUEST["cvmodule"]);
 $mode = $_REQUEST["mode"];
 $subject = $_REQUEST["subject"];
 $body = $_REQUEST["body"];
@@ -50,4 +49,4 @@ if($cvid != "")
 	}
 }
 header("Location: index.php?action=index&module=$cvmodule&viewname=$cvid");
-?>
+?>
\ No newline at end of file
