@@ -1,26 +1,23 @@
 <?php
-/*********************************************************************************
-** The contents of this file are subject to the vtiger CRM Public License Version 1.0
+/*+********************************************************************************
+ * The contents of this file are subject to the vtiger CRM Public License Version 1.0
  * ("License"); You may not use this file except in compliance with the License
  * The Original Code is:  vtiger CRM Open Source
  * The Initial Developer of the Original Code is vtiger.
  * Portions created by vtiger are Copyright (C) vtiger.
  * All Rights Reserved.
-*
  ********************************************************************************/
 
 require_once('include/database/PearDatabase.php');
 
 //Getting the Parameters from the Convert Form
-$id = $_REQUEST["record"];
-$module = $_REQUEST["module"];
-$assigned_user_id = $_REQUEST["assigned_user_id"];
-$createpotential = $_REQUEST["createpotential"];
-$potential_name = $_REQUEST["potential_name"];
-$close_date = $_REQUEST["closedate"];
-$current_user_id = $_REQUEST["current_user_id"];
-
-//$id=$adb->query_result($adb->query('select * from vtiger_users where user_name="'.$_REQUEST['assigned_user_id'].'"'),0,"id");
+$id = vtlib_purify($_REQUEST["record"]);
+$module = vtlib_purify($_REQUEST["module"]);
+$assigned_user_id = vtlib_purify($_REQUEST["assigned_user_id"]);
+$createpotential = vtlib_purify($_REQUEST["createpotential"]);
+$potential_name = vtlib_purify($_REQUEST["potential_name"]);
+$close_date = vtlib_purify($_REQUEST["closedate"]);
+$current_user_id = vtlib_purify($_REQUEST["current_user_id"]);
 
 $idlist=split(';',$_REQUEST['idlist']);
 
@@ -45,4 +42,4 @@ for($i=0;$i<count($idlist);$i++)
 }
 header("Location: index.php?action=index&module=HelpDesk");
 
-?>
+?>
\ No newline at end of file
