@@ -27,6 +27,12 @@ function fetchAddSite(id)
 
 function fetchContents(mode)
 {
+	// Reloading the window is better, If not reloaded ... mysitesArray variable needs to be updated
+	// using eval method on javascript. 
+	if(mode == 'data') {
+		window.location.href = 'index.php?module=Portal&action=ListView&parenttab=Tools';
+		return;
+	}
 	$("status").style.display="inline";
 	new Ajax.Request(
                 'index.php',
