@@ -28,6 +28,13 @@ $mod_strings = array(
 'LBL_PB_LIST_PRICE'=>'List Price',
 'LBL_ACTION'=>'Action',
 'PriceBook'=>'Price Book',
+
+// Added after 5.0.4 GA
+'Currency'=>'Currency',
+
+// Module Sequence Numbering
+'PriceBook No' => 'PriceBook No',
+// END
 );
 
 
