@@ -1,20 +1,20 @@
 <?php
-/*********************************************************************************
- ** The contents of this file are subject to the vtiger CRM Public License Version 1.0
-  * ("License"); You may not use this file except in compliance with the License
-  * The Original Code is:  vtiger CRM Open Source
-  * The Initial Developer of the Original Code is vtiger.
-  * Portions created by vtiger are Copyright (C) vtiger.
-  * All Rights Reserved.
- *
-  ********************************************************************************/
+/*+********************************************************************************
+ * The contents of this file are subject to the vtiger CRM Public License Version 1.0
+ * ("License"); You may not use this file except in compliance with the License
+ * The Original Code is:  vtiger CRM Open Source
+ * The Initial Developer of the Original Code is vtiger.
+ * Portions created by vtiger are Copyright (C) vtiger.
+ * All Rights Reserved.
+ *********************************************************************************/
 
 require_once('include/logging.php');
-require_once('modules/Quotes/Quotes.php');
 require_once('include/database/PearDatabase.php');
 global $adb;
 
 $local_log =& LoggerManager::getLogger('QuotesAjax');
+global $currentModule;
+$modObj = CRMEntity::getInstance($currentModule);
 
 $ajaxaction = $_REQUEST["ajxaction"];
 if($ajaxaction == "DETAILVIEW")
@@ -25,7 +25,6 @@ if($ajaxaction == "DETAILVIEW")
 	$fieldvalue = utf8RawUrlDecode($_REQUEST["fieldValue"]); 
 	if($crmid != "")
 	{
-		$modObj = new Quotes();
 		$modObj->retrieve_entity_info($crmid,"Quotes");
 		$modObj->column_fields[$fieldname] = $fieldvalue;
 		$modObj->id = $crmid;
@@ -43,4 +42,4 @@ if($ajaxaction == "DETAILVIEW")
 		echo ":#:FAILURE";
 	}
 }
-?>
+?>
\ No newline at end of file
