@@ -22,17 +22,14 @@
 
 require_once('Smarty_setup.php');
 require_once('data/Tracker.php');
-require_once('modules/Quotes/Quotes.php');
 require_once('include/CustomFieldUtil.php');
-require_once('include/ComboUtil.php');
 require_once('include/utils/utils.php');
-require_once('include/FormValidationUtil.php');
 
 global $app_strings,$mod_strings,$log,$theme,$currentModule,$current_user;
 
 $log->debug("Inside Quote EditView");
 
-$focus = new Quotes();
+$focus = CRMEntity::getInstance($currentModule);
 $smarty = new vtigerCRM_Smarty;
 //added to fix the issue4600
 $searchurl = getBasic_Advance_SearchURL();
@@ -43,37 +40,69 @@ $currencyid=fetchCurrency($current_user->id);
 $rate_symbol = getCurrencySymbolandCRate($currencyid);
 $rate = $rate_symbol['rate'];
 
-if(isset($_REQUEST['record']) && $_REQUEST['record'] != '') 
-{
+if(isset($_REQUEST['record']) && $_REQUEST['record'] != ''){
     $focus->id = $_REQUEST['record'];
     $focus->mode = 'edit'; 
     $log->debug("Mode is Edit. Quoteid is ".$focus->id);
     $focus->retrieve_entity_info($_REQUEST['record'],"Quotes");		
     $focus->name=$focus->column_fields['subject']; 
 }
+
 if(isset($_REQUEST['isDuplicate']) && $_REQUEST['isDuplicate'] == 'true') {
 	$smarty->assign("DUPLICATE_FROM", $focus->id);
-        $QUOTE_associated_prod = getAssociatedProducts("Quotes",$focus);
+	$QUOTE_associated_prod = getAssociatedProducts("Quotes",$focus);
 	$log->debug("Mode is Duplicate. Quoteid to be duplicated is ".$focus->id);
 	$focus->id = "";
     	$focus->mode = ''; 	
 }
-if(isset($_REQUEST['potential_id']) && $_REQUEST['potential_id'] !='')
-{
-        $focus->column_fields['potential_id'] = $_REQUEST['potential_id'];
-	$_REQUEST['account_id'] = get_account_info($focus->column_fields['potential_id']);
-	 $log->debug("Quotes EditView: Potential Id from the request is ".$_REQUEST['potential_id']);
-        $associated_prod = getAssociatedProducts("Potentials",$focus,$focus->column_fields['potential_id']);
+if(empty($_REQUEST['record']) && $focus->mode != 'edit'){
+	setObjectValuesFromRequest($focus);
 }
-if(isset($_REQUEST['product_id']) && $_REQUEST['product_id'] !='')
-{
-        $focus->column_fields['product_id'] = $_REQUEST['product_id'];
-        $log->debug("Productid Id from the request is ".$_REQUEST['product_id']);
-        $associated_prod = getAssociatedProducts("Products",$focus,$focus->column_fields['product_id']);
+
+if(isset($_REQUEST['potential_id']) && $_REQUEST['potential_id'] !=''){
+	$focus->column_fields['potential_id'] = $_REQUEST['potential_id'];
+	$relatedInfo = getRelatedInfo($_REQUEST['potential_id']);
+	if(!empty($relatedInfo)){
+		$setype = $relatedInfo["setype"];
+		$relID = $relatedInfo["relID"];
+	}
+	if($setype == 'Accounts'){
+		$_REQUEST['account_id'] = $relID;
+	}elseif($setype == 'Contacts'){
+		$_REQUEST['contact_id'] = $relID;
+	}
+	$log->debug("Quotes EditView: Potential Id from the request is ".$_REQUEST['potential_id']);
+	$associated_prod = getAssociatedProducts("Potentials",$focus,$focus->column_fields['potential_id']);
+}
+
+if(isset($_REQUEST['product_id']) && $_REQUEST['product_id'] !=''){
+    $focus->column_fields['product_id'] = $_REQUEST['product_id'];
+    $log->debug("Product Id from the request is ".$_REQUEST['product_id']);
+    $associated_prod = getAssociatedProducts("Products",$focus,$focus->column_fields['product_id']);
+	for ($i=1; $i<=count($associated_prod);$i++) {
+		$associated_prod_id = $associated_prod[$i]['hdnProductId'.$i];
+		$associated_prod_prices = getPricesForProducts($currencyid,array($associated_prod_id),'Products');
+		$associated_prod[$i]['listPrice'.$i] = $associated_prod_prices[$associated_prod_id];
+	}
 	$smarty->assign("ASSOCIATEDPRODUCTS", $associated_prod);
 	$smarty->assign("AVAILABLE_PRODUCTS", 'true');
 }
 
+if(!empty($_REQUEST['parent_id']) && !empty($_REQUEST['return_module'])){
+    if ($_REQUEST['return_module'] == 'Services') {
+	    $focus->column_fields['product_id'] = $_REQUEST['parent_id'];
+	    $log->debug("Service Id from the request is ".$_REQUEST['parent_id']);
+	    $associated_prod = getAssociatedProducts("Services",$focus,$focus->column_fields['product_id']);
+		for ($i=1; $i<=count($associated_prod);$i++) {
+			$associated_prod_id = $associated_prod[$i]['hdnProductId'.$i];
+			$associated_prod_prices = getPricesForProducts($currencyid,array($associated_prod_id),'Services');
+			$associated_prod[$i]['listPrice'.$i] = $associated_prod_prices[$associated_prod_id];
+		}
+	   	$smarty->assign("ASSOCIATEDPRODUCTS", $associated_prod);
+		$smarty->assign("AVAILABLE_PRODUCTS", 'true');
+    }
+}
+
 // Get Account address if vtiger_account is given
 if(isset($_REQUEST['account_id']) && $_REQUEST['account_id']!='' && $_REQUEST['record']==''){
 	require_once('modules/Accounts/Accounts.php');
@@ -97,10 +126,6 @@ if(isset($_REQUEST['account_id']) && $_REQUEST['account_id']!='' && $_REQUEST['r
 
 $theme_path="themes/".$theme."/";
 $image_path=$theme_path."images/";
-//retreiving the combo values array
-$comboFieldNames = Array('accounttype'=>'account_type_dom'
-                      ,'industry'=>'industry_dom');
-$comboFieldArray = getComboArray($comboFieldNames);
 
 $disp_view = getView($focus->mode);
 $mode = $focus->mode;
@@ -110,7 +135,6 @@ else
 {
 	$bas_block = getBlocks($currentModule,$disp_view,$mode,$focus->column_fields,'BAS');
 	$adv_block = getBlocks($currentModule,$disp_view,$mode,$focus->column_fields,'ADV');
-	
 	$blocks['basicTab'] = $bas_block;
 	if(is_array($adv_block ))
 		$blocks['moreTab'] = $adv_block;
@@ -119,7 +143,6 @@ else
 	$smarty->assign("BLOCKS_COUNT",count($blocks));
 }
 $smarty->assign("OP_MODE",$disp_view);
-
 $smarty->assign("MODULE",$currentModule);
 $smarty->assign("SINGLE_MOD",'Quote');
 $category = getParentTab();
@@ -162,9 +185,9 @@ elseif((isset($_REQUEST['potential_id']) && $_REQUEST['potential_id'] != '') ||
 	//this is to display the Product Details in first row when we create new PO from Product relatedlist
 	if($_REQUEST['return_module'] == 'Products')
 	{
-		$smarty->assign("PRODUCT_ID",$_REQUEST['product_id']);
+		$smarty->assign("PRODUCT_ID",vtlib_purify($_REQUEST['product_id']));
 		$smarty->assign("PRODUCT_NAME",getProductName($_REQUEST['product_id']));
-		$smarty->assign("UNIT_PRICE",getUnitPrice($_REQUEST['product_id']));
+		$smarty->assign("UNIT_PRICE",vtlib_purify($_REQUEST['product_id']));
 		$smarty->assign("QTY_IN_STOCK",getPrdQtyInStck($_REQUEST['product_id']));
 		$smarty->assign("VAT_TAX",getProductTaxPercentage("VAT",$_REQUEST['product_id']));
 		$smarty->assign("SALES_TAX",getProductTaxPercentage("Sales",$_REQUEST['product_id']));
@@ -176,18 +199,16 @@ else
 	$smarty->assign("ROWCOUNT", '1');
 }
 
-
-if(isset($_REQUEST['return_module'])) $smarty->assign("RETURN_MODULE", $_REQUEST['return_module']);
+if(isset($_REQUEST['return_module'])) $smarty->assign("RETURN_MODULE", vtlib_purify($_REQUEST['return_module']));
 else $smarty->assign("RETURN_MODULE","Quotes");
-if(isset($_REQUEST['return_action'])) $smarty->assign("RETURN_ACTION", $_REQUEST['return_action']);
+if(isset($_REQUEST['return_action'])) $smarty->assign("RETURN_ACTION", vtlib_purify($_REQUEST['return_action']));
 else $smarty->assign("RETURN_ACTION","index");
-if(isset($_REQUEST['return_id'])) $smarty->assign("RETURN_ID", $_REQUEST['return_id']);
-if(isset($_REQUEST['return_viewname'])) $smarty->assign("RETURN_VIEWNAME", $_REQUEST['return_viewname']);
+if(isset($_REQUEST['return_id'])) $smarty->assign("RETURN_ID", vtlib_purify($_REQUEST['return_id']));
+if(isset($_REQUEST['return_viewname'])) $smarty->assign("RETURN_VIEWNAME", vtlib_purify($_REQUEST['return_viewname']));
 $smarty->assign("THEME", $theme);
 $smarty->assign("IMAGE_PATH", $image_path);$smarty->assign("PRINT_URL", "phprint.php?jt=".session_id().$GLOBALS['request_string']);
 $smarty->assign("ID", $focus->id);
 
-
 $smarty->assign("CALENDAR_LANG", $app_strings['LBL_JSCALENDAR_LANG']);
 $smarty->assign("CALENDAR_DATEFORMAT", parse_calendardate($app_strings['NTC_DATE_FORMAT']));
 
@@ -218,10 +239,38 @@ $smarty->assign("MODULE", $module);
 
 $check_button = Button_Check($module);
 $smarty->assign("CHECK", $check_button);
-$smarty->assign("DUPLICATE", $_REQUEST['isDuplicate']);
+$smarty->assign("DUPLICATE",vtlib_purify($_REQUEST['isDuplicate']));
+
+global $adb;
+// Module Sequence Numbering
+$mod_seq_field = getModuleSequenceField($currentModule);
+if($focus->mode != 'edit' && $mod_seq_field != null) {
+		$autostr = getTranslatedString('MSG_AUTO_GEN_ON_SAVE');
+		$mod_seq_string = $adb->pquery("SELECT prefix, cur_id from vtiger_modentity_num where semodule = ? and active=1",array($currentModule));
+        $mod_seq_prefix = $adb->query_result($mod_seq_string,0,'prefix');
+        $mod_seq_no = $adb->query_result($mod_seq_string,0,'cur_id');
+        if($adb->num_rows($mod_seq_string) == 0 || $focus->checkModuleSeqNumber($focus->table_name, $mod_seq_field['column'], $mod_seq_prefix.$mod_seq_no))
+                echo '<br><font color="#FF0000"><b>'. getTranslatedString('LBL_DUPLICATE'). ' '. getTranslatedString($mod_seq_field['label'])
+                	.' - '. getTranslatedString('LBL_CLICK') .' <a href="index.php?module=Settings&action=CustomModEntityNo&parenttab=Settings&selmodule='.$currentModule.'">'.getTranslatedString('LBL_HERE').'</a> '
+                	. getTranslatedString('LBL_TO_CONFIGURE'). ' '. getTranslatedString($mod_seq_field['label']) .'</b></font>';
+        else
+                $smarty->assign("MOD_SEQ_ID",$autostr);
+} else {
+	$smarty->assign("MOD_SEQ_ID", $focus->column_fields[$mod_seq_field['name']]);
+}
+// END
+
+$smarty->assign("CURRENCIES_LIST", getAllCurrencies());
+if($focus->mode == 'edit' || $_REQUEST['isDuplicate'] == 'true') {
+	$inventory_cur_info = getInventoryCurrencyInfo('Quotes', $focus->id);
+	$smarty->assign("INV_CURRENCY_ID", $inventory_cur_info['currency_id']);
+} else {
+	$smarty->assign("INV_CURRENCY_ID", $currencyid);
+}
+
 if($focus->mode == 'edit')
 	$smarty->display("Inventory/InventoryEditView.tpl");
 else
 	$smarty->display('Inventory/InventoryCreateView.tpl');
 
-?>
+?>
\ No newline at end of file
