@@ -1,16 +1,15 @@
 <?php
-/*********************************************************************************
-** The contents of this file are subject to the vtiger CRM Public License Version 1.0
+/*+********************************************************************************
+ * The contents of this file are subject to the vtiger CRM Public License Version 1.0
  * ("License"); You may not use this file except in compliance with the License
  * The Original Code is:  vtiger CRM Open Source
  * The Initial Developer of the Original Code is vtiger.
  * Portions created by vtiger are Copyright (C) vtiger.
  * All Rights Reserved.
-*
  ********************************************************************************/
 
 require_once('include/database/PearDatabase.php');
-global $adb;
+global $adb, $mod_strings;
 $rolename = $_REQUEST['roleName'];
 $mode = $_REQUEST['mode'];
 if(isset($_REQUEST['dup_check']) && $_REQUEST['dup_check']!='')
@@ -29,11 +28,11 @@ if(isset($_REQUEST['dup_check']) && $_REQUEST['dup_check']!='')
 	$result = $adb->pquery($query, $params);
 	if($adb->num_rows($result) > 0)
 	{
-		echo 'Role name already exists';
+		echo $mod_strings['LBL_ROLENAME_EXIST'];
 		die;
 	}else
 	{
-		echo 'SUCESS';
+		echo 'SUCCESS';
 		die;
 	}
 
@@ -63,4 +62,4 @@ elseif(isset($_REQUEST['mode']) && $_REQUEST['mode'] == 'create')
 
 $loc = "Location: index.php?action=listroles&module=Settings&parenttab=Settings";
 header($loc);
-?>
+?>
\ No newline at end of file
