@@ -12,14 +12,14 @@
 require_once('config.php');
 require_once('include/database/PearDatabase.php');
 
-global $fileId;
+global $fileId, $default_charset;
 
 $templateid = $_REQUEST['record'];
 $dbQuery = "SELECT filename,filetype, data ";
 $dbQuery .= "FROM vtiger_wordtemplates ";
-$dbQuery .= "WHERE templateid=" .$templateid;
+$dbQuery .= "WHERE templateid=?";
 
-$result = $adb->query($dbQuery) or die("Couldn't get file list");
+$result = $adb->pquery($dbQuery, array($templateid)) or die("Couldn't get file list");
 if($adb->num_rows($result) == 1)
 {
 $fileType = $adb->query_result($result, 0, "filetype");
@@ -27,6 +27,7 @@ $name = $adb->query_result($result, 0, "filename");
 //echo 'filetype is ' .$fileType;
 $fileContent = $adb->query_result($result, 0, "data");
 $size = $adb->query_result($result, 0, "filesize");
+$name = html_entity_decode($name, ENT_QUOTES, $default_charset);
 header("Content-type: $fileType");
 //header("Content-length: $size");
 header("Cache-Control: private");
