@@ -8,8 +8,8 @@
  * All Rights Reserved.
 *
  ********************************************************************************/
-
-set_time_limit(-1);
+global $php_max_execution_time;
+set_time_limit($php_max_execution_time);
 RecalculateSharingRules();
 
 header("Location: index.php?action=OrgSharingDetailView&parenttab=Settings&module=Settings");
